<?php
/*
 * Phake - Mocking Framework
 *
 * Copyright (c) 2010-2012, Mike Lively <m@digitalsandwich.com>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *  *  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *  *  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *  *  Neither the name of Mike Lively nor the names of his
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * @category   Testing
 * @package    Phake
 * @author     Mike Lively <m@digitalsandwich.com>
 * @copyright  2010 Mike Lively <m@digitalsandwich.com>
 * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
 * @link       http://www.digitalsandwich.com/
 */

/**
 * A call or set of calls that was expected
 */
class Phake_CallRecorder_CallExpectation
{
	/**
	 * @var Phake_IMock
	 */
	private $object;

	/**
	 * @var string
	 */
	private $method;

	/**
	 * @var array
	 */
	private $argumentMatchers;

	/**
	 * @var Phake_CallRecorder_IVerifierMode
	 */
	private $verifierMode;
	
	/**
	 * @var Phake_MockReader
	 */
	private $mockReader;

	/**
	 * @param Phake_IMock $object
	 * @param string $method
	 * @param array $argumentMatchers
	 * @param Phake_CallRecorder_IVerifierMode $verificationMode
	 * @param Phake_MockReader $mockReader
	 * @return void
	 */
	public function __construct(Phake_IMock $object, $method, array $argumentMatchers, Phake_CallRecorder_IVerifierMode $verificationMode, Phake_MockReader $mockReader)
	{
		$this->object = $object;
		$this->method = $method;
		$this->argumentMatchers = $argumentMatchers;
		$this->verifierMode = $verificationMode;
		$this->mockReader = $mockReader;
	}

	/**
	 * @return Phake_IMock
	 */
	public function getObject()
	{
		return $this->object;
	}

	/**
	 * @return string
	 */
	public function getMethod()
	{
		return $this->method;
	}

	/**
	 * @return array
	 */
	public function getArgumentMatchers()
	{
		return $this->argumentMatchers;
	}

	/**
	 * @return Phake_CallRecorder_IVerifierMode
	 */
	public function getVerifierMode()
	{
		return $this->verifierMode;
	}

	public function __toString()
	{
		$arguments = array();
		foreach ($this->argumentMatchers as $argumentMatcher)
		{
			$arguments[] = $argumentMatcher->__toString();
		}

		return "Expected {$this->mockReader->getName($this->getObject())}->{$this->getMethod()}(" . implode(', ', $arguments) . ") to be called {$this->getVerifierMode()->__toString()}";
	}
}
